@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2005-2021 Intel Corporation
+    Copyright (c) 2005-2022 Intel Corporation
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -145,12 +145,12 @@ namespace r1 {
 
 #if __TBB_WIN8UI_SUPPORT
     bool dynamic_link( const char*  library, const dynamic_link_descriptor descriptors[], std::size_t required, dynamic_link_handle*, int flags ) {
-        dynamic_link_handle tmp_handle = NULL;
+        dynamic_link_handle tmp_handle = nullptr;
         TCHAR wlibrary[256];
         if ( MultiByteToWideChar(CP_UTF8, 0, library, -1, wlibrary, 255) == 0 ) return false;
         if ( flags & DYNAMIC_LINK_LOAD )
             tmp_handle = LoadPackagedLibrary( wlibrary, 0 );
-        if (tmp_handle != NULL){
+        if (tmp_handle != nullptr){
             return resolve_symbols(tmp_handle, descriptors, required);
         }else{
             return false;
@@ -239,7 +239,7 @@ namespace r1 {
         char *backslash = std::strrchr( ap_data._path, '\\' );
 
         if ( !backslash ) {    // Backslash not found.
-            __TBB_ASSERT_EX( backslash!=NULL, "Unbelievable.");
+            __TBB_ASSERT_EX( backslash != nullptr, "Unbelievable.");
             return;
         }
         __TBB_ASSERT_EX( backslash >= ap_data._path, "Unbelievable.");
@@ -254,7 +254,7 @@ namespace r1 {
             DYNAMIC_LINK_WARNING( dl_sys_fail, "dladdr", err );
             return;
         } else {
-            __TBB_ASSERT_EX( dlinfo.dli_fname!=NULL, "Unbelievable." );
+            __TBB_ASSERT_EX( dlinfo.dli_fname!=nullptr, "Unbelievable." );
         }
 
         char const *slash = std::strrchr( dlinfo.dli_fname, '/' );
@@ -316,12 +316,12 @@ namespace r1 {
         std::size_t name_len = std::strlen( name );
         std::size_t full_len = name_len+ap_data._len;
         if ( full_len < len ) {
-            __TBB_ASSERT( ap_data._path[ap_data._len] == 0, NULL);
-            __TBB_ASSERT( std::strlen(ap_data._path) == ap_data._len, NULL);
+            __TBB_ASSERT( ap_data._path[ap_data._len] == 0, nullptr);
+            __TBB_ASSERT( std::strlen(ap_data._path) == ap_data._len, nullptr);
             std::strncpy( path, ap_data._path, ap_data._len + 1 );
-            __TBB_ASSERT( path[ap_data._len] == 0, NULL );
+            __TBB_ASSERT( path[ap_data._len] == 0, nullptr);
             std::strncat( path, name, len - ap_data._len );
-            __TBB_ASSERT( std::strlen(path) == full_len, NULL );
+            __TBB_ASSERT( std::strlen(path) == full_len, nullptr);
         }
         return full_len+1; // +1 for null character
     }
@@ -444,7 +444,7 @@ namespace r1 {
                 if( !resolve_symbols( library_handle, descriptors, required ) ) {
                     // The loaded library does not contain all the expected entry points
                     dynamic_unlink( library_handle );
-                    library_handle = NULL;
+                    library_handle = nullptr;
                 }
             } else
                 DYNAMIC_LINK_WARNING( dl_lib_not_found, path, dlerror() );
@@ -454,14 +454,14 @@ namespace r1 {
                 // rc == 0 means failing of init_ap_data so the warning has already been issued.
 
 #endif /* __TBB_DYNAMIC_LOAD_ENABLED */
-            return 0;
+            return nullptr;
     }
 
     bool dynamic_link( const char* library, const dynamic_link_descriptor descriptors[], std::size_t required, dynamic_link_handle *handle, int flags ) {
         init_dynamic_link_data();
 
         // TODO: May global_symbols_link find weak symbols?
-        dynamic_link_handle library_handle = ( flags & DYNAMIC_LINK_GLOBAL ) ? global_symbols_link( library, descriptors, required ) : 0;
+        dynamic_link_handle library_handle = ( flags & DYNAMIC_LINK_GLOBAL ) ? global_symbols_link( library, descriptors, required ) : nullptr;
 
 #if defined(_MSC_VER) && _MSC_VER <= 1900
 #pragma warning (push)
